Crate miden_core_lib

Crate miden_core_lib 

Modules

dsa
Digital Signature Algorithm (DSA) helper functions.
handlers

Structs

CoreLibrary
The Miden core library, providing a set of optimized procedures for Miden programs.

Constants

PVM_PROOF_REQUEST_EVENT_NAME
Event emitted by sys::pvm::request_proof to request an asynchronously supplied PVM proof package. The PVM verifier root is at stack positions 1 through 4 and the deferred root is at positions 5 through 8.

Functions

conjectured_security_estimator_root
Returns the MAST root of the common recursive conjectured security estimator.