sign

Function sign 

pub fn sign(sk: &SecretKey, msg: Word) -> Vec<Felt>
Signs the provided message with the supplied secret key and encodes this signature and the associated public key into a vector of field elements in the format expected by miden::core::crypto::dsa::eddsa_ed25519::verify procedure.

See encode_signature() for more info.