sign

Function sign 

pub fn sign(sk: &SecretKey, msg: Word) -> Option<Vec<Felt>>
Signs the provided message with the provided secret key and returns the resulting signature encoded in the format required by the falcon512_poseidon2::verify procedure, or None if the secret key is malformed due to either incorrect length or failed decoding.

This is equivalent to calling encode_signature on the result of signing the message.

See encode_signature for the encoding format.