handle_smt_peek

Function handle_smt_peek 

pub fn handle_smt_peek(
    process: &ProcessorState<'_>,
) -> Result<Vec<AdviceMutation>, EventError>
SMT_PEEK system event handler.

Pushes onto the advice stack the value associated with the specified key in a Sparse Merkle Tree defined by the specified root.

If no value was previously associated with the specified key, [ZERO; 4] is pushed onto the advice stack.

Inputs: Operand stack: [event_id, KEY, ROOT, …] Advice stack: […]

Outputs: Advice stack: [VALUE, …]

Errors

Returns an error if the provided Merkle root doesn’t exist on the advice provider.

Panics

Will panic as unimplemented if the target depth is 64.