Crate miden_core_lib
miden_
core_
lib
0.32.0
All Items
Crate Items
Modules
Structs
Constants
Functions
Crate
miden_
core_
lib
Modules

dsa
Digital Signature Algorithm (DSA) helper functions.
handlers
Structs

Core
Library
The Miden core library, providing a set of optimized procedures for Miden programs.
Constants

PVM_
PROOF_
REQUEST_
EVENT_
NAME
Event emitted by
sys::pvm::request_proof
to request an asynchronously supplied PVM proof package. The PVM verifier root is at stack positions 1 through 4 and the deferred root is at positions 5 through 8.
Functions

conjectured_
security_
estimator_
root
Returns the MAST root of the common recursive conjectured security estimator.